@@ -260,6 +260,20 @@ class StreamChatInterface(abc.ABC):
         """
         pass
 
+    @abc.abstractmethod
+    def get_rate_limits(self, server_side, android, ios, web, endpoints):
+        """
+        Get rate limit quotas and usage.
+        If no params are toggled, all limits for all endpoints are returned.
+
+        :param server_side: if true, show server_side limits.
+        :param android: if true, show android limits.
+        :param ios: if true, show ios limits.
+        :param web: if true, show web limits.
+        :param endpoints: restrict returned limits to the given list of endpoints.
+        """
+        pass
+
     @abc.abstractmethod
     def search(self, filter_conditions, query, **options):
         pass
@@ -318,7 +332,7 @@ class StreamChatInterface(abc.ABC):
         pass
 
     @abc.abstractmethod
-    async def check_sqs(self, sqs_key=None, sqs_secret=None, sqs_url=None):
+    def check_sqs(self, sqs_key=None, sqs_secret=None, sqs_url=None):
         """
         Check SQS Push settings
 
@@ -330,3 +344,72 @@ class StreamChatInterface(abc.ABC):
         :return:
         """
         pass
+
+    @abc.abstractmethod
+    def get_permission(self, name):
+        """
+        Get the definition for a permission
+
+        :param name: Name of the permission
+        """
+        pass
+
+    @abc.abstractmethod
+    def create_permission(self, permission):
+        """
+        Create a custom permission
+
+        :param permission: Definition of the permission
+        """
+        pass
+
+    @abc.abstractmethod
+    def update_permission(self, name, permission):
+        """
+        Update a custom permission
+
+        :param name: Name of the permission
+        :param permission: New definition of the permission
+        """
+        pass
+
+    @abc.abstractmethod
+    def delete_permission(self, name):
+        """
+        Delete a custom permission
+
+        :param name: Name of the permission
+        """
+        pass
+
+    @abc.abstractmethod
+    def list_permissions(self):
+        """
+        List custom permissions of the app
+        """
+        pass
+
+    @abc.abstractmethod
+    def create_role(self, name):
+        """
+        Create a custom role
+
+        :param name: Name of the role
+        """
+        pass
+
+    @abc.abstractmethod
+    def delete_role(self, name):
+        """
+        Delete a custom role
+
+        :param name: Name of the role
+        """
+        pass
+
+    @abc.abstractmethod
+    def list_roles(self):
+        """
+        List custom roles of the app
+        """
+        pass
