@@ -267,6 +267,33 @@ class StreamChat(StreamChatInterface):
         """
         return self.get("devices", {"user_id": user_id})
 
+    def get_rate_limits(
+        self, server_side=False, android=False, ios=False, web=False, endpoints=None
+    ):
+        """
+        Get rate limit quotas and usage.
+        If no params are toggled, all limits for all endpoints are returned.
+
+        :param server_side: if true, show server_side limits.
+        :param android: if true, show android limits.
+        :param ios: if true, show ios limits.
+        :param web: if true, show web limits.
+        :param endpoints: restrict returned limits to the given list of endpoints.
+        """
+        params = {}
+        if server_side:
+            params["server_side"] = "true"
+        if android:
+            params["android"] = "true"
+        if ios:
+            params["ios"] = "true"
+        if web:
+            params["web"] = "true"
+        if endpoints is not None and len(endpoints) > 0:
+            params["endpoints"] = ",".join(endpoints)
+
+        return self.get("rate_limits", params)
+
     def search(self, filter_conditions, query, **options):
         params = {**options, "filter_conditions": filter_conditions, "query": query}
         return self.get("search", params={"payload": json.dumps(params)})
@@ -347,3 +374,64 @@ class StreamChat(StreamChatInterface):
         """
         data = {"sqs_key": sqs_key, "sqs_secret": sqs_secret, "sqs_url": sqs_url}
         return self.post("check_sqs", data=data)
+
+    def get_permission(self, name):
+        """
+        Get the definition for a permission
+
+        :param name: Name of the permission
+        """
+        return self.get(f"custom_permission/{name}")
+
+    def create_permission(self, permission):
+        """
+        Create a custom permission
+
+        :param permission: Definition of the permission
+        """
+        return self.post("custom_permission", data=permission)
+
+    def update_permission(self, name, permission):
+        """
+        Update a custom permission
+
+        :param name: Name of the permission
+        :param permission: New definition of the permission
+        """
+        return self.post(f"custom_permission/{name}", data=permission)
+
+    def delete_permission(self, name):
+        """
+        Delete a custom permission
+
+        :param name: Name of the permission
+        """
+        return self.delete(f"custom_permission/{name}")
+
+    def list_permissions(self):
+        """
+        List custom permissions of the app
+        """
+        return self.get("custom_permission")
+
+    def create_role(self, name):
+        """
+        Create a custom role
+
+        :param name: Name of the role
+        """
+        return self.post("custom_role", data={"name": name})
+
+    def delete_role(self, name):
+        """
+        Delete a custom role
+
+        :param name: Name of the role
+        """
+        return self.delete(f"custom_role/{name}")
+
+    def list_roles(self):
+        """
+        List custom roles of the app
+        """
+        return self.get("custom_role")
